@@ -1,5 +1,5 @@
 import numpy as np
-import pandas as pd 
+import pandas as pd
 
 def evidencegapmap(dataset, x_column, y_column, xy_column=None, bubble_column=None, bubble_text=None, bubble_link=None, time_column=None, size_column=None, color_column=None,   
                xbin_list=None, ybin_list=None,xbin_size=100, ybin_size=100, x_title=None, y_title=None, title=None, colorbar_title=None,
@@ -223,7 +223,7 @@ def make_grid_with_categories(dataset, column_names, time_column, category_colum
     that is unavailable in the offline mode for plotly. The grids are designed using the `col_name_template`
     from the `column_names` of the `dataset` using the `category_column` for catergories.'''
     
-    grid = pd.DataFrame()
+    grid = pandas.DataFrame()
     if categories is None:
         categories = dataset[category_column].unique()
     if time_column:
